@@ -143,7 +143,10 @@ class RegexURLPattern(LocaleRegexProvider):
             callback = callback.func
         if not hasattr(callback, '__name__'):
             return callback.__module__ + "." + callback.__class__.__name__
+        elif six.PY3:
+            return callback.__module__ + "." + callback.__qualname__
         else:
+            # PY2 does not support __qualname__
             return callback.__module__ + "." + callback.__name__
 
 
